Package 'quadprogXT'

Title: Quadratic Programming with Absolute Value Constraints
Description: Extends the quadprog package to solve quadratic programs with absolute value constraints and absolute values in the objective function.
Authors: Bob Harlow [aut, cre], Brian Koch [ctb]
Maintainer: Bob Harlow <[email protected]>
License: GPL(>=2)
Version: 0.0.6
Built: 2026-05-12 05:21:59 UTC
Source: https://github.com/rharlow86/quadprogxt

Help Index